@@ -466,9 +466,9 @@ class Process(SystemObjectDescription):
             recipe = BNode()
             g.add((uri, PROBS_RECIPE.hasRecipe, recipe))
             for item in recipe_consumes:
-                g.add((recipe, PROBS.consumes, item))
+                g.add((recipe, PROBS_RECIPE.consumes, item))
             for item in recipe_produces:
-                g.add((recipe, PROBS.produces, item))
+                g.add((recipe, PROBS_RECIPE.produces, item))
 
         if "become_parent" in self.options:
             # print("xxx become parent")
@@ -660,15 +660,23 @@ class ObjectIndex(Index):
         for process_name, objs in process_consumes.items():
             for obj in objs:
                 if ("object." + obj["object"]) not in objects:
-                    msg = "WARNING: Object {} consumed by process {} is not defined"
-                    print(msg.format(obj["object"], process_name))
+                    logger.error(
+                        "Object %s consumed by process %s is not defined",
+                        obj["object"],
+                        process_name,
+                        # location=(self.env.docname, self.lineno)
+                    )
                     continue
                 object_processes[obj["object"]].append((process_name, "consumed"))
         for process_name, objs in process_produces.items():
             for obj in objs:
                 if ("object." + obj["object"]) not in objects:
-                    msg = "WARNING: Object {} produced by process {} is not defined"
-                    print(msg.format(obj["object"], process_name))
+                    logger.error(
+                        "Object %s produced by process %s is not defined",
+                        obj["object"],
+                        process_name,
+                        # location=(self.env.docname, self.lineno)
+                    )
                     continue
                 object_processes[obj["object"]].append((process_name, "produced"))
 
@@ -739,7 +747,9 @@ class SystemDomain(Domain):
     }
 
     def get_full_qualified_name(self, node):
-        return "{}.{}".format("system", node.arguments[0])
+        if node.get("refdomain") == "system":
+            return "{}.{}".format("system", node.get("reftarget"))
+        return None
 
     def get_objects(self):
         for obj in self.data["processes"]:
@@ -760,9 +770,8 @@ class SystemDomain(Domain):
 
             # print("system domain: found %s %s %r xref" % (todocname, targ, target))
             return make_refnode(builder, fromdocname, todocname, targ, contnode, targ)
-        else:
-            print("system domain: found nothing for %r xref" % target)
-            return None
+
+        return None
 
     def add_process(self, signature, consumes, produces):
         """Add a new process to the domain."""
